function  [r_p,r_z,rScaling,tol_inn,mit_inn,tol_outite,U0,Weights,chk_opt_u,issingle,idisp] = getALMTVL1opts(opts)
% parameters setting for all TVL1-like problems using augmented Lagrangian
% method.
%
% Input: opts -- can be a structure with following fields or empty
%
% Outputs:     
%               r_p -- the penalty parameter in the AL functional for
%                      p = \nabla u
%               r_z -- the penalty parameter in the AL functional for
%                      z = Ku
%          rScaling -- the scaling factor of the penalty parameter.
%           tol_inn -- controls inner iteration optimality conditions
%           mit_inn -- if accuracy tol_inn is not acheived in mit_inn
%                      steps, then jump out that inner iteation and go
%                      ahead
%                U0 -- initial guess of solution
%           Weights -- local weights for TV
%         chk_opt_u -- determin whether or not to check the optimality of u
%                      after both res_wn and res_wz satisfy the stopping 
%                      criterion. Since res_u usually (seems always) is 
%                      more easy to satisfy the stopping criterion, if one 
%                      want to save cpu time, just set chk_opt_u = 0.
%          issingle -- controls computation data type is single or not?
%             idisp -- controls if middle iteraiton info is displayed
%

% Default setting
r_p = 20;% can be modified.
r_z = 100;% can be modified.
rScaling = 1;
tol_inn = 5.e-2;
mit_inn = 1;
tol_outite = 0.4;% can be modified.
U0 = [];
Weights = 1;
chk_opt_u = 0;
issingle = 0;
idisp = 1;



if ~isempty(opts);
    if ~isa(opts,'struct'); error('opts not a struct'); end
    if isfield(opts,'r_p')&&(~isempty(opts.r_p));
        r_p = opts.r_p; end;
    if isfield(opts,'r_z')&&(~isempty(opts.r_z));
        r_z = opts.r_z; end;
    if isfield(opts,'rScaling')&&(~isempty(opts.rScaling));
        rScaling = opts.rScaling; end;
    if isfield(opts,'tol_inn')&&(~isempty(opts.tol_inn)); 
        tol_inn = opts.tol_inn; end;
    if isfield(opts,'tol_outite')&&(~isempty(opts.tol_outite)); 
        tol_outite = opts.tol_outite; end;
    if isfield(opts,'mit_inn')&&(~isempty(opts.mit_inn));
        mit_inn = opts.mit_inn; end;
    if isfield(opts,'U0')&&(~isempty(opts.U0));
        U0 = opts.U0; end;
    if isfield(opts,'Weights')&&(~isempty(opts.Weights)); 
        Weights = opts.Weights; end;
    if isfield(opts,'chk_opt_u') && (~isempty(opts.chk_opt_u));
        chk_opt_u = opts.chk_opt_u; end;    
    if isfield(opts,'issingle'); issingle = opts.issingle; end;
    if isfield(opts,'idisp')&&(~isempty(opts.idisp));  
        idisp = opts.idisp; end;    
end;

